@@ -2,6 +2,7 @@ from pydantic import BaseModel
 from typing import Optional, List
 from enum import IntEnum
 from agricore_sp_models.common_models import OrganicProductionType, ProductGroupJsonDTO
+from pydantic import confloat
     
 class AgriculturalProduction(BaseModel):
     id: Optional[int] = None
@@ -193,6 +194,7 @@ class CropDataDTO(BaseModel):
     cropProductiveArea: float
     cropVariableCosts: float
     quantitySold: float
+    quantityUsed: float
     cropSellingPrice: float
     coupledSubsidy: float
     uaa: float
@@ -258,7 +260,7 @@ class LandTransaction(BaseModel):
     productionId: int
     destinationFarmId: int
     yearId: int
-    percentage: float
+    percentage: confloat(ge=0, le=1)
     salePrice: float
 
 class AgroManagementDecisions(BaseModel):
