@@ -1,4 +1,4 @@
-from agricore_sp_models.common_models import OrganicProductionType, ProductGroupJsonDTO
+from agricore_sp_models.common_models import OrganicProductionType, PolicyJsonDTO, ProductGroupJsonDTO
 from pydantic import BaseModel, Field
 from typing import List
 
@@ -115,6 +115,7 @@ class PopulationJsonDTO(BaseModel):
     description: str = ""
     farms: List[FarmJsonDTO]
     productGroups: List[ProductGroupJsonDTO]
+    uncoupledPolicies: List[PolicyJsonDTO]
 
 class SyntheticPopulationJsonDTO(BaseModel):
     description: str = ""
