@@ -14,8 +14,8 @@ class SimulationScenario(BaseModel):
     yearId: int
     ignoreLP: Optional[bool]
     ignoreLMM: Optional[bool]
-    yearToContinueFrom: Optional[int] = 0
-    stageToContinueFrom: Optional[SimulationStage] = SimulationStage.DATAPREPARATION
+    yearToContinueFrom: Optional[int] = None
+    stageToContinueFrom: Optional[SimulationStage] = None
     shortTermModelBranch: str
     longTermModelBranch: str
     horizon: int
